============
Liquimigrate
============

.. image:: https://img.shields.io/travis/onjin/liquimigrate.svg
        :target: https://travis-ci.org/onjin/liquimigrate

.. image:: https://img.shields.io/pypi/v/liquimigrate.svg
        :target: https://pypi.python.org/pypi/liquimigrate


Liquibase migrations for Django

* License: BSD
* Documentation: https://liquimigrate.readthedocs.org.
